@@ -8,7 +8,7 @@ use MooX::Cmd;
 use BioX::Map;
 use Types::Standard qw(Int Str Bool Enum);
 
-our $VERSION = '0.0.7'; # VERSION:
+our $VERSION = '0.0.8'; # VERSION:
 # ABSTRACT: a wrapper for mapping software
 
 
@@ -92,6 +92,7 @@ option tool => (
 
 sub execute {
   my ($self, $args_ref, $chain_ref) = @_;
+  my $stamp = time;
   my $pre_message = "please input parameters, genome is required, either infile or indir is required";
   my ($infile, $indir, $outfile, $outdir) = ($self->infile, $self->indir, $self->outfile, $self->outdir);
   $self->options_usage(1, $pre_message) unless ($infile or $indir);
@@ -107,6 +108,8 @@ sub execute {
     process_sample  => $process_sample,
   );
   $bm->map;
+  my $m = time - $stamp;
+  say "duration second:" . (time - $stamp) . "\nduration minute:" . (int($m/60));
 }
 
 1;
@@ -123,7 +126,7 @@ BioX::Map::CLIS::Cmd::Map - a wrapper for mapping software
 
 =head1 VERSION
 
-version 0.0.7
+version 0.0.8
 
 =head1 SYNOPSIS
 
