@@ -8,7 +8,7 @@ use MooX::Cmd;
 use BioX::Map;
 use Types::Standard qw(Int Str Bool Enum);
 
-our $VERSION = '0.0.7'; # VERSION:
+our $VERSION = '0.0.8'; # VERSION:
 # ABSTRACT: a wrapper for mapping software
 
 
@@ -84,6 +84,7 @@ option tool => (
 
 sub execute {
   my ($self, $args_ref, $chain_ref) = @_;
+  my $stamp = time;
   my $pre_message = "please input parameters, indir is required";
   my ($indir, $outdir) = ($self->indir, $self->outdir);
   $self->options_usage(1, $pre_message) unless ( $indir);
@@ -101,6 +102,8 @@ sub execute {
   $bm->map;
   my $summary = $self->summary_file;
   system("biox-map compare -i $outdir -o $summary -s soap -b bwa");
+  my $m = time - $stamp;
+  say "duration second" . (time - $stamp) . "\nduration minute" . (int ($m / 60));
 }
 
 1;
@@ -117,7 +120,7 @@ BioX::Map::CLIS::Cmd::MapCompare - a wrapper for mapping software
 
 =head1 VERSION
 
-version 0.0.7
+version 0.0.8
 
 =head1 SYNOPSIS
 
